# Author:  Janet Rogers
# Date:    4 April 2012
# Version: ArcGIS 10.0
# Purpose: This script will iterate through each MXD in a folder and report information about each
#          map document's layers.  The script is intended to run from a script
#          tool that requires two input parameters:
#               1) folder containing MXDs,
#               2) an output text file.
#
#          The resulting text file will automatically open.
# Base code copied from ESRI mxd_list.py http://forums.arcgis.com/threads/55215-list-all-data-sources-used-in-MXD-or-batch-of-MXDs-in-a-text-file

import arcpy, datetime, os, xlrd

try:

    arcpy.gp.overwriteOutput = True

    #Read input parameters from GP dialog
    folderPath = arcpy.GetParameterAsText(0)
    output = arcpy.GetParameterAsText(1)

    #Create an output file
    outFile = open(output, "w")
    count = 0
    thePattern = '.mxd'
    #Loop through the folders and subfolders
    for dir, subdirs, files in os.walk(folderPath):
        for f in files:
            if f[-4:].lower() == thePattern:
                fullpath =  os.path.join(dir, f)
                if os.path.isfile(fullpath):

                    #Reference MXD
                    mxd = arcpy.mapping.MapDocument(fullpath)
                    count = 1

                    #Reference each data frame and report data
                    DFList = arcpy.mapping.ListDataFrames(mxd)
                    for df in DFList:

                        #Reference each layer in a data frame
                        lyrList = arcpy.mapping.ListLayers(mxd, "", df)
                        for lyr in lyrList:
                            #Write MXD data to file
                            outFile.write( mxd.filePath + "\t")
                            #Write Layer data to file
                            layr = lyr.name
                            layr = layr.replace('\r\n','')
                            outFile.write( layr + "\t")
                            #Write Datasource to file
                            if lyr.supports("dataSource"):
                                outFile.write(lyr.dataSource + "\n")
                            else: outFile.write(" N/A \n")


                    del mxd

    if count ==0:
        outFile.write("NO MXD FILES FOUND \n")
    outFile.close()

    #Open resulting text file
    os.startfile(output)
    #rdbook = xlrd.open_workbook(output, formatting_info=True)

    #Delete variables that reference data on disk
    del folderPath, output, outFile, fullpath
    print 'Complete'

except Exception, e:
  import traceback
  map(arcpy.AddError, traceback.format_exc().split("\n"))
  arcpy.AddError(str(e))